; Example shows how to work with the Description property of a Layer.
(defun c:layerDescription-NoCatch ( / acDoc acLayer acLayers
                                      strLayerName strLayerDesc)
  ; Check to see if the Visual LISP ActiveX functions have been loaded
  (if (/= (type vlax-get-property) 'SUBR)(vl-load-com))
  
  ; Define custom error handler
  (setq old_err *error*)

  ; Define custom error handler
  (defun *error* (msg)
    (if (= (type msg) 'STR)
      (prompt (strcat "\nerror: " msg))
    )

    ; Restore previous error handler
    (if (/= old_err nil)
      (setq *error* old_err
            old_err nil)
    )
   (princ)
  )
  
  ; Get the active drawing and Layers collection
  (setq acDoc (vlax-get-property
		(vlax-get-acad-object) 'ActiveDocument)
        acLayers (vlax-get-property acDoc 'Layers)
  )

  ; Request the name of the layer to modify
  (while (/= (setq strLayerName
		    (getstring T
		      "\nEnter layer name to add description to: ")) "")

    ; Check to see if the Layer exists in the drawing
    (if (/= (vla-item acLayers strLayerName))
      (progn
	; Layer exists so ask for a description to add to the Layer
        (setq strLayerDesc
	       (getstring T "\nEnter description for layer: "))

	; If the user just pressed enter then remove the description
        (if (= strLayerDesc nil)(setq strLayerDesc ""))

	; Change the Description for the Layer
        (vlax-put-property
          (vla-item acLayers strLayerName) 'Description strLayerDesc)
      )
    )
  )

  ; Restore previous error handler
  (if (/= old_err nil)
    (setq *error* old_err
          old_err nil)
  )
  
 (princ)
)


; Example shows how to work with the Description property of a Layer.
(defun c:layerDescription-WithCatch ( / acDoc acLayer acLayers
                                        strLayerName strLayerDesc)
  ; Check to see if the Visual LISP ActiveX functions have been loaded
  (if (/= (type vlax-get-property) 'SUBR)(vl-load-com))
  
  ; Get the active drawing and Layers collection
  (setq acDoc (vlax-get-property
		(vlax-get-acad-object) 'ActiveDocument)
        acLayers (vlax-get-property acDoc 'Layers)
  )

  ; Request the name of the layer to modify
  (while (/= (setq strLayerName
                   (getstring T
		     "\nEnter layer name to add description to: ")) "")

    ; Check to see if the Layer exists in the drawing
    (if (not (vl-catch-all-error-p
               (setq err
                     (vl-catch-all-apply 'vla-item
		       (list acLayers strLayerName)))))
      (progn
        ; Layer exists so ask for a description to add to the Layer
        (setq strLayerDesc
	       (getstring T "\nEnter description for layer: "))

        ; If the user jsut pressed enter then remove the description
        (if (= strLayerDesc nil)(setq strLayerDesc ""))

        ; Change the Description for the Layer
        (vlax-put-property
          (vla-item acLayers strLayerName) 'Description strLayerDesc)
      )
      (progn
        (prompt (strcat "\nerror: " (vl-catch-all-error-message err)))
        (setq strLayerName "")
      )
    )
  )
  
 (princ)
)