; Load COM environment
(vl-load-com)

; Create a Blue Circle using Visual LISP
(defun c:CreateCircle-VL ( / acadObj docObj spaceObj cenPoint circObj)
  ; Create a reference to AutoCAD
  (setq acadObj (vlax-get-acad-object))

  (debug acadObj)
  
  ; Create a reference to the current drawing
  (setq docObj (vla-get-activedocument acadObj))

  (debug acadObj)
  (debug "Determine current space")
  
  ; Get a reference to the current space
  (if (= (vla-get-activespace docObj) acModelSpace)
    (setq spaceObj (vla-get-modelspace docObj))
    (setq spaceObj (vla-get-paperspace docObj))
  )

  (debug spaceObj)  
  (debug "Start object definition")
  
  ; Create the center point for the circle
  (setq cenPoint (vlax-make-safearray vlax-vbdouble '(0 . 2)))
  (vlax-safearray-fill cenPoint '(5.0 5.0 0.0))

  (debug cenPoint)
  
  ; Create a circle at 5,5 in a radius of 1.75
  (setq circObj (vla-addcircle spaceObj cenPoint 1.75))

  (debug circObj)
  
  ; Change the color of the circle to blue
  (vla-put-color circObj 5)

  (debug "End object definition")
 (princ)
)


; Global debugging variables
; *GLOBAL-DEBUG-LOGFILE* - Logfile name and location
; *GLOBAL-DEBUG-LOGGING* - Log enabled
; *GLOBAL-DEBUG-ENABLED* - Enable debugging (T or nil)

; Enable debugging - Example usage (debug-mode 2)
(defun debug-mode (enable / )
  (cond
    ((or (= enable 0)(= enable nil))
      (if (= (type *GLOBAL-DEBUG-LOGFILE*) 'FILE)
        (progn
	  (close *GLOBAL-DEBUG-LOGFILE*)
	  (setq *GLOBAL-DEBUG-LOGFILE* nil)
	)
      )

      (setq *GLOBAL-DEBUG-ENABLED* nil
            *GLOBAL-DEBUG-LOGGING* nil
            *GLOBAL-DEBUG-LOGFILE* nil)
    )
    ((or (= enable 1)(= enable T))
      (setq *GLOBAL-DEBUG-ENABLED* 1 *GLOBAL-DEBUG-LOGGING* 0)
      (if (= (type *GLOBAL-DEBUG-LOGFILE*) 'FILE)
        (progn
	  (close *GLOBAL-DEBUG-LOGFILE*)
	  (setq *GLOBAL-DEBUG-LOGFILE* nil)
	)
      )
    )
    ((= enable 2)
      (setq *GLOBAL-DEBUG-ENABLED* 1 *GLOBAL-DEBUG-LOGGING* 1)
      (if (/= (type *GLOBAL-DEBUG-LOGFILE*) 'FILE)
        (setq *GLOBAL-DEBUG-LOGFILE* (open (strcat (getvar "tempprefix") "global-debug.log") "a"))
      )  
    )
  )
 (princ)
)

; Get the current state of debugging
(defun debug-get-enabled ( / )
  *GLOBAL-DEBUG-ENABLED*
)

; Get the current logging state
(defun debug-get-logmode ( / )
  *GLOBAL-DEBUG-LOGGING*
)

; Get the name of the current log file
(defun debug-get-logfile ( / )
  *GLOBAL-DEBUG-LOGFILE*
)

; Debug function that is a wrapper for the functionality
; of the princ and prin1 functions. Feature is turned on or
; off based on the function debug-mode.
; Off, Command prompt echo, or External file write
(defun debug (value / )
  (if (debug-get-enabled)
    (if (/= (debug-get-logmode) 1)
      (progn (princ value)(terpri))
      (print value (debug-get-logfile))
    )
  )
 (princ)
)