;; Returns the three letter language code from the product key
;; Usage: (returnLanguageCode)
(defun returnLanguageCode ( / )
  (strcase
    (substr (vlax-product-key)
      (- (strlen (vlax-product-key)) 2)
    )
  )
)

; Main function, message returned is based on the AutoCAD product language version
(defun evaluate (/ languageCode)
  (setq languageCode (returnLanguageCode))
  
  (alert
    (cond ((= languageCode "409") ; English message
            "Command started."
          )
          ((= languageCode "40C") ; French message
            "Commande a commenc."
          )
    )
  )
)

;; Defines a global and local command based on the AutoCAD product language version
(cond ((= (returnLanguageCode) "409")
        (vlax-add-cmd "evaluate" 'evaluate "evaluate")
      )
      ((= (returnLanguageCode) "40C")
        (vlax-add-cmd "evaluate" 'evaluate "evaluer") ; Actual translation is "valuer"
      )
)


;; Helper function that returns a resource string based on language code
;; Usage: (returnLocalizedString "SAMPLE" 3)
(defun returnLocalizedString (programName resourceID / 
                              languageCode)

  ;; Get the language code for the current product
  (setq languageCode (returnLanguageCode))

  ;; Get a text string based on program name and resource ID from the list
  (cond ((= (strcase programName) "SAMPLE")	 
          (cond ((= languageCode "409") ; English text strings
                  (cdr (assoc resourceID '(
                                           (1 . "ABC")
                                           (2 . "One")
                                           (3 . "White")
                                           (4 . "XYZ")
                                          )
                  ))
                )
                ((= languageCode "40C") ; French text strings
                  (cdr (assoc resourceID '(
                                           (1 . "ABC")
                                           (2 . "Un")
                                           (3 . "Blanc")
                                           (4 . "XYZ")
                                          )
                  ))
                )
          )
        )
  )
)