;; Created by: Lee Ambrosius
;; These is a custom LSP program that is used for the session:
;; SD20507 - Deploy and Support AutoLISP Programs Like a Pro

; Zoom shortcuts
(defun c:ZW ( / )  (command "._zoom" "_w"))
(defun c:ZP ( / )  (command "._zoom" "_p"))

; Inserts the drawing file b-tblk.dwg
(defun c:TB ( / old-layer)
  ; Save the current layer
  (setq old-layer (getvar "clayer"))

  ; Create a new layer named TitleBlk
  (create-layer "TitleBlk" "7")

  ; Insert the title block
  (command "._insert" "b-tblk.dwg" "0,0" 1 1 0)

  ; Restore the previous layer
  (setvar "clayer" old-layer)
 (princ)
)

; Runs the script file named startup.scr
(defun c:SU ( / )
  ; Check for the startup.scr file
  (if (findfile "startup.scr")
    (command "._script" "startup.scr")
    (alert "MISSING FILE: File startup.script could not be found.")
  )
 (princ)
)

; Repeat Purge command 3 times to remove nested objects
; and remove zero lines and empty objects
(defun c:P3 ( / )
  ; Repeat the PURGE command 3 times
  (repeat 3
    (command "._-purge" "_all" "*" "_n")
  )

  ; Purge lines of zero-length and empty text objects
  (command "._-purge" "_z")
  (command "._-purge" "_e")
 (princ)
)

; Create a tag with leader
(defun TagBubble ( / old-layer old-osmode old-cmdecho
                     cenPt tagLineEndPt)
  (terpri) ; Make sure the prompts start on a new line
  (prompt "\nThis routine creates a tag bubble.")

  ; Saves some of the system variables values
  (setq old-layer (getvar "clayer"))
  (setq old-osmode (getvar "osmode"))
  (setq old-cmdecho (getvar "cmdecho"))

  ; Disables command echo
  (setvar "cmdecho" 0)

  ; Creates a new layer named Bubbles
  (create-layer "Bubbles" "3")

  ; Sets the initial default value
  (if (= tagShape nil)
     (setq tagShapeDef "Circle")
  )

  ; Prompts the user for a bubble shape
  (initget "Circle Square Hexagon _Circle Square Hexagon")
  (setq tagShape (getkword 
                    (strcat "\nEnter shape [Circle/Square/Hexagon] <"
                            tagShapeDef ">: "
                    )
                 )
  )

  ; If the user pressed Enter, pass the previous default value along
  (if (= tagShape nil)
     (setq tagShape tagShapeDef)
  )

  ; Save the bubble choice as the next default value
  (setq tagShapeDef tagShape)

  ; Prompt for the size of the bubble shape
  (prompt "\nSize must be >=  3.0000.")
  (if (= tagSize nil)
    (setq tagSizeNew (getreal "\nSpecify tag size <3.0000>: "))
    (setq tagSizeNew (getreal (strcat "\nSpecify tag size <" (rtos tagSize) ">: ")))
  )
  (if (and (/= tagSizeNew nil) (>= tagSizeNew 3))
     (setq tagSize tagSizeNew tagSizeNew nil)
     (progn
       (setq tagSize 3)
       (prompt "\nTag size set to 3.0000.\n")
     )
  )

  ; Draw the bubble
  (cond
    ((= tagShape "Square") (command "._polygon" 4 (setq cenPT (getpoint)) "_I" tagSize))
    ((= tagShape "Hexagon") (command "._polygon" 6 (setq cenPT (getpoint)) "_I" tagSize))
    (T (command "._circle" (setq cenPT (getpoint)) tagSize))
  )

  ; Create a layer for the leader lines
  (create-layer "Lines" "5")

  ; Specify for the end point of the leader line
  ;(setq cenPt (getvar "lastpoint"))
  (setq tagLineEndPt (getpoint cenPt "\nSpecify endpoint: "))
  (setvar "osmode" 16432)  ; Disable object snaps before drawing the leader line

  ; Draw the leader line
  ; (command "._line" tagLineStartPt tagLineEndPt "")
  (command "._select" "_L" "")
  (command "._line" cenPt tagLineEndPt "")

  ; Trim the leader line to the shape of the bubble
  (command "._trim" "_P" "" cenPt "")

  ; Adds text to the bubble
  (command "._-text" "_J" "_MC" cenPt (* tagSize 0.67) 0 "X")

  ; Restore the saved system variable values
  (setvar "cmdecho" old-cmdecho)
  (setvar "osmode" old-osmode)
  (setvar "clayer" old-layer)
)

(vlax-add-cmd "TagBubble" 'TagBubble "TagBubble")

(princ)